Package: ReliaLearnR
Type: Package
Title: Learning Modules for Reliability Analysis
Version: 0.5
URL: https://paulgovan.github.io/ReliaLearnR/,
        https://github.com/paulgovan/ReliaLearnR
BugReports: https://github.com/paulgovan/ReliaLearnR/issues
Authors@R: person("Paul", "Govan", email = "paul.govan2@gmail.com", role = c("aut", "cre", "cph"), 
  comment = c(ORCID = "0000-0002-1821-8492"))
Description: Learning modules for reliability analysis including modules for Reliability,
  Availability, and Maintainability (RAM) Analysis, Life Data Analysis, Reliability Testing,
  Repairable Systems Analysis, and Reliability Block Diagrams.
Depends: R (>= 4.1.0)
Imports: learnr (>= 0.11.0), ReliaGrowR, WeibullR, WeibullR.ALT
Suggests: DiagrammeR, knitr, mockery, ReliaPlotR, ReliaShiny,
        rmarkdown, testthat (>= 3.0.0)
License: Apache License (>= 2)
Encoding: UTF-8
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-27 12:36:06 UTC; paulgovan
Author: Paul Govan [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-1821-8492>)
Maintainer: Paul Govan <paul.govan2@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-27 13:00:02 UTC
Built: R 4.5.2; ; 2026-05-27 14:38:51 UTC; unix
