# Generated by roxygen2: do not edit by hand

export(avail)
export(fr)
export(lda)
export(mtbf)
export(mttf)
export(ram)
export(rbd)
export(rel)
export(rs)
export(rt)
import(ReliaGrowR)
import(WeibullR)
import(WeibullR.ALT)
importFrom(learnr,run_tutorial)
