
#' Launch the Reliability Block Diagram Tutorial
#'
#' This function launches an interactive tutorial on Reliability Block Diagrams
#' and system reliability, covering series, parallel, mixed, and k-out-of-n
#' configurations as well as an introduction to Fault Tree Analysis.
#' @importFrom learnr run_tutorial
#' @export
#' @seealso \url{https://paulgovan.github.io/ReliaLearnR/}
#' @return This function does not return a value.
#' @examples
#' if (interactive()) {
#'   rbd()
#' }
rbd <- function() {
  learnr::run_tutorial("rbd", package = "ReliaLearnR")
}
