% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/helpers.R
\name{fr}
\alias{fr}
\title{Failure rate (lambda)}
\usage{
fr(failures, totalTime)
}
\arguments{
\item{failures}{Numeric scalar or numeric vector of failure counts (non-negative).}

\item{totalTime}{Numeric scalar or numeric vector of total operating times.}
}
\value{
Numeric scalar: failures per unit time (failures / totalTime).
}
\description{
Failure rate is the frequency with which an engineered system or component fails,
expressed in failures per unit of time. This function computes failure rate given
failure counts and total operating times.
}
\examples{
fr(75, 5000)
fr(c(10,5), c(1000,2000))
}
