% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/helpers.R
\name{rel}
\alias{rel}
\title{Reliability (1 - outage / total)}
\usage{
rel(outageTime, totalTime)
}
\arguments{
\item{outageTime}{Numeric scalar or numeric vector of forced outage times.}

\item{totalTime}{Numeric scalar or numeric vector of total times (same units as outageTime).}
}
\value{
Numeric scalar: reliability for the period (between 0 and 1).
}
\description{
Reliability is the probability that an item will perform its intended function
without failure over a specified period under stated conditions. This function
computes reliability given outage times and total times.
}
\examples{
rel(100, 1000)
rel(c(10,20), c(500, 600))
}
